
From: Nishanth Aravamudan <nacc@us.ibm.com>

Use schedule_timeout_interruptible() instead of
set_current_state()/schedule_timeout() to reduce kernel size.

Signed-off-by: Nishanth Aravamudan <nacc@us.ibm.com>
Cc: "Moore, Eric Dean" <Eric.Moore@lsil.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/message/fusion/mptlan.c   |   10 ++++------
 drivers/message/fusion/mptscsih.c |    6 ++----
 drivers/message/i2o/iop.c         |   15 +++++----------
 3 files changed, 11 insertions(+), 20 deletions(-)

diff -puN drivers/message/fusion/mptlan.c~message-fix-up-schedule_timeout-usage drivers/message/fusion/mptlan.c
--- devel/drivers/message/fusion/mptlan.c~message-fix-up-schedule_timeout-usage	2005-09-11 02:06:29.000000000 -0700
+++ devel-akpm/drivers/message/fusion/mptlan.c	2005-09-11 02:06:29.000000000 -0700
@@ -506,7 +506,7 @@ mpt_lan_close(struct net_device *dev)
 {
 	struct mpt_lan_priv *priv = netdev_priv(dev);
 	MPT_ADAPTER *mpt_dev = priv->mpt_dev;
-	unsigned int timeout;
+	unsigned long timeout;
 	int i;
 
 	dlprintk((KERN_INFO MYNAM ": mpt_lan_close called\n"));
@@ -521,11 +521,9 @@ mpt_lan_close(struct net_device *dev)
 
 	mpt_lan_reset(dev);
 
-	timeout = 2 * HZ;
-	while (atomic_read(&priv->buckets_out) && --timeout) {
-		set_current_state(TASK_INTERRUPTIBLE);
-		schedule_timeout(1);
-	}
+	timeout = jiffies + 2 * HZ;
+	while (atomic_read(&priv->buckets_out) && time_before(jiffies, timeout))
+		schedule_timeout_interruptible(1);
 
 	for (i = 0; i < priv->max_buckets_out; i++) {
 		if (priv->RcvCtl[i].skb != NULL) {
diff -puN drivers/message/fusion/mptscsih.c~message-fix-up-schedule_timeout-usage drivers/message/fusion/mptscsih.c
--- devel/drivers/message/fusion/mptscsih.c~message-fix-up-schedule_timeout-usage	2005-09-11 02:06:29.000000000 -0700
+++ devel-akpm/drivers/message/fusion/mptscsih.c	2005-09-11 02:06:29.000000000 -0700
@@ -981,10 +981,8 @@ mptscsih_remove(struct pci_dev *pdev)
 	spin_lock_irqsave(&dvtaskQ_lock, flags);
 	if (dvtaskQ_active) {
 		spin_unlock_irqrestore(&dvtaskQ_lock, flags);
-		while(dvtaskQ_active && --count) {
-			set_current_state(TASK_INTERRUPTIBLE);
-			schedule_timeout(1);
-		}
+		while(dvtaskQ_active && --count)
+			schedule_timeout_interruptible(1);
 	} else {
 		spin_unlock_irqrestore(&dvtaskQ_lock, flags);
 	}
diff -puN drivers/message/i2o/iop.c~message-fix-up-schedule_timeout-usage drivers/message/i2o/iop.c
--- devel/drivers/message/i2o/iop.c~message-fix-up-schedule_timeout-usage	2005-09-11 02:06:29.000000000 -0700
+++ devel-akpm/drivers/message/i2o/iop.c	2005-09-11 02:06:29.000000000 -0700
@@ -92,8 +92,7 @@ u32 i2o_msg_get_wait(struct i2o_controll
 				  c->name);
 			return I2O_QUEUE_EMPTY;
 		}
-		set_current_state(TASK_UNINTERRUPTIBLE);
-		schedule_timeout(1);
+		schedule_timeout_uninterruptible(1);
 	}
 
 	return m;
@@ -484,8 +483,7 @@ static int i2o_iop_init_outbound_queue(s
 			osm_warn("%s: Timeout Initializing\n", c->name);
 			return -ETIMEDOUT;
 		}
-		set_current_state(TASK_UNINTERRUPTIBLE);
-		schedule_timeout(1);
+		schedule_timeout_uninterruptible(1);
 	}
 
 	m = c->out_queue.phys;
@@ -547,8 +545,7 @@ static int i2o_iop_reset(struct i2o_cont
 		if (time_after(jiffies, timeout))
 			break;
 
-		set_current_state(TASK_UNINTERRUPTIBLE);
-		schedule_timeout(1);
+		schedule_timeout_uninterruptible(1);
 	}
 
 	switch (*status) {
@@ -576,8 +573,7 @@ static int i2o_iop_reset(struct i2o_cont
 				rc = -ETIMEDOUT;
 				goto exit;
 			}
-			set_current_state(TASK_UNINTERRUPTIBLE);
-			schedule_timeout(1);
+			schedule_timeout_uninterruptible(1);
 
 			m = i2o_msg_get_wait(c, &msg, I2O_TIMEOUT_RESET);
 		}
@@ -987,8 +983,7 @@ int i2o_status_get(struct i2o_controller
 			return -ETIMEDOUT;
 		}
 
-		set_current_state(TASK_UNINTERRUPTIBLE);
-		schedule_timeout(1);
+		schedule_timeout_uninterruptible(1);
 	}
 
 #ifdef DEBUG
_
